Index: /issm/trunk/cron/README
===================================================================
--- /issm/trunk/cron/README	(revision 41)
+++ /issm/trunk/cron/README	(revision 42)
@@ -7,5 +7,5 @@
 For example, if you add: 
 
-5 5 * * * cd $ICEHOME/Cron && ./ice.sh
+5 5 * * * cd $ISSM_DIR/cron && ./nightlyrun.sh
 
 This will run all the scripts in the Cron directory, every day, at 5:05 am. 
@@ -13,4 +13,4 @@
 
 
-If users want to add their own scripts, just add the script to the Cron directory and
-add an entry in the ice.sh for this script.
+If users want to add their own scripts, just add the script to the cron directory and
+add an entry in the issm.sh for this script.
Index: sm/trunk/cron/ice.sh
===================================================================
--- /issm/trunk/cron/ice.sh	(revision 41)
+++ 	(revision )
@@ -1,8 +1,0 @@
-#!/bin/bash
-
-
-#Run tagging of ICE code
-./tag.sh
-
-#Run nightly run
-./nightlyrun.sh
Index: sm/trunk/cron/killingforeign.sh
===================================================================
--- /issm/trunk/cron/killingforeign.sh	(revision 41)
+++ 	(revision )
@@ -1,20 +1,0 @@
-#!/bin/bash
-#This script will run anything popping up in the current directory, using the Cielo 
-#software. 
-
-#Get paths correctly setup
-source ~/.bash_profile
-
-#Ok, we are being launched by the cron job. We are going through all the files, detecting which 
-#ones have a .kill attached to them.  source the kill file.
-
-numberoffiles=`ls *.kill 2> /dev/null | wc -l`
-
-if [[ $numberoffiles != 0 ]]
-then
-	for i  in *.kill
-	do
-		name=`echo $i | sed 's/.kill//'`
-		source $name.kill
-	done
-fi
Index: /issm/trunk/cron/linux_cronfile
===================================================================
--- /issm/trunk/cron/linux_cronfile	(revision 41)
+++ /issm/trunk/cron/linux_cronfile	(revision 42)
@@ -1,3 +1,1 @@
-#05 0 * * * cd $HOME/Ice/ice1/cron/ && ./ice.sh
-*/5 * * * * cd $HOME/TestingForeign/ && source /u/wilkes-r1b/larour/Ice/ice1.proto/cron/testingforeign.sh
-*/5 * * * * cd $HOME/TestingForeign/ && source /u/wilkes-r1b/larour/Ice/ice1.proto/cron/killingforeign.sh
+#05 0 * * * cd $HOME/Ice/issm/trunk/cron/ && ./nightlyrun.sh
Index: sm/trunk/cron/list
===================================================================
--- /issm/trunk/cron/list	(revision 41)
+++ 	(revision )
@@ -1,11 +1,0 @@
-CVS
-ice.sh
-killingforeign.sh
-linux_cronfile
-list
-mailinglist
-Makefile.am
-nightlyrun.sh
-README
-tag.sh
-testingforeign.sh
Index: sm/trunk/cron/tag.sh
===================================================================
--- /issm/trunk/cron/tag.sh	(revision 41)
+++ 	(revision )
@@ -1,39 +1,0 @@
-#!/bin/bash
-
-release=ice1
-repository=/home/larour/Ice_Repository
-home=/home/seroussi
-current=`pwd`
-
-#Functions
-
-function today_date {
-suffix=`date | awk '{printf("%s-%s-%s",$2,$3,$6);}'` 
-echo $suffix;
-}
-
-#Date
-today=`today_date`;
-
-#Go to home directory
-cd $home
-
-#Erase to make a fresh tag;
-if [ -d $release ] 
-then
-	rm -rf $release
-fi
-
-#Fetch cvs release
-cvs -d $repository co -P $release 
-
-#Tag cvs
-cd $release
-cvs -d $repository tag -R $today 
-cd ../
-
-#Erase cvs release
-rm -rf "./$release"
-
-#Go back to current directory
-cd $current
Index: sm/trunk/cron/testingforeign.sh
===================================================================
--- /issm/trunk/cron/testingforeign.sh	(revision 41)
+++ 	(revision )
@@ -1,25 +1,0 @@
-#!/bin/bash
-#This script will run anything popping up in the current directory, using the Cielo 
-#software. 
-
-#Get paths correctly setup
-source ~/.bash_profile
-
-#Ok, we are being launched by the cron job. We are going through all the files, detecting which 
-#ones have a .queue attached to them. For those files, check whether a .errlog and .outlog are already present.
-#If they are, skip this file, it is already being run. For the other ones, source the queue file.
-
-numberoffiles=`ls *.queue 2> /dev/null | wc -l`
-
-if [[ $numberoffiles != 0 ]]
-then
-	for i  in *.queue
-	do
-		name=`echo $i | sed 's/.queue//'`
-		if [ ! -e $name.outlog ]
-		then
-			#Launch "name" job
-			source $name.queue
-		fi
-	done
-fi

Index: /issm/trunk/cron/nightlyrun.sh
===================================================================
--- /issm/trunk/cron/nightlyrun.sh	(revision 41)
+++ /issm/trunk/cron/nightlyrun.sh	(revision 42)
@@ -9,8 +9,8 @@
 }
 
-export ISSM_DIR="/home/seroussi/Ice/ice1/cron/ice1"
-
-ICE_RELEASE="ice1";
-ICE_REPOSITORY="/home/larour/Ice_Repository";
+#create ISSM variables
+OLDISSM_DIR=$ISSM_DIR;
+export ISSM_DIR="/home/morlighe/Ice/issm/trunk/cron/issm/trunk"
+ISSM_RELEASE="issm";
 
 #Figure out today's date
@@ -19,19 +19,40 @@
 
 #Erase code
-rm -rf $ICE_RELEASE
+rm -rf $ISSM_RELEASE
 
-#Fetch cvs code
-cvs -d $ICE_REPOSITORY co -P $ICE_RELEASE
+#Fetch svn code
+svn checkout file:///u/wilkes-r1b/larour/Repository/issm
 
 source $ISSM_DIR/etc/environment.sh
 
-#Go to the ice directory
-cd $ICE_RELEASE
-ICEDIR=`pwd`;
+#Go to the issm directory
+cd $ISSM_DIR
 
 #install ISSM
-cd scripts
-sh quickinstall.sh
+
+#1: install some packages
+cd externalpackages
+cd mpich2
+sh install.sh
+cd ../petsc
+sh install.sh
+cd ../metis
+sh install.sh
+cd ../triangle
+sh install.sh
+cd $ISSM_DIR
+
+#2: install automake and autoconf
+cd devpackages
+make
 cd ..
+
+#3: generate MakeFiles
+./reconfigure.sh
+./configure.sh
+
+#4: compile ISSM
+make
+make install
 
 #Figure out mailing list
@@ -54,10 +75,10 @@
 	for i in `echo $MAILINGLIST`
 		do
-			mail -s "Nightly runs of $ICE_RELEASE on: $host_name. Date:$today. DID NOT WORK CORRECTLY" $i < nightly.log
+			mail -s "Nightly runs of $ISSM_RELEASE on: $host_name. Date:$today. DID NOT WORK CORRECTLY" $i < nightly.log
 		done
 else
 	for i in `echo $MAILINGLIST`
 		do  
-			mail -s "Nightly runs of $ICE_RELEASE on: $host_name. Date:$today." $i < errors.log
+			mail -s "Nightly runs of $ISSM_RELEASE on: $host_name. Date:$today." $i < errors.log
 		done
 fi
@@ -68,5 +89,5 @@
 #Erase ice code
 cd ..
-rm -rf $ICE_RELEASE
+rm -rf $ISSM_RELEASE
 
 #back to old ISSM_DIR